# Source

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**source_orcid** | [**SourceOrcid**](SourceOrcid.md) |  | [optional] 
**source_client_id** | [**SourceClientId**](SourceClientId.md) |  | [optional] 
**source_name** | [**SourceName**](SourceName.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


